# Python Janeiro

Python framework that cleanly takes care of micro-service technical details and let you focus on building high value software.

[![Rio de Janeiro](docs/img/janeiro.jpg)](https://www.youtube.com/watch?v=2GZwbKnjRyE)

## Features

* [Configuration management](./docs/configuration.md)
* [Configurable logging](./docs/logging.md)
